#include "stdafx.h"
#include "PrinterEvents.h"
#include <afxctl.h>

IMPLEMENT_DYNAMIC(CPrinterEvents, CCmdTarget)

CPrinterEvents::CPrinterEvents()
{
	m_dwConnectionCookie	= 0;
	m_hEnvent				= INVALID_HANDLE_VALUE;
	m_pPrinter				= nullptr;
	//
	EnableAutomation();
}

CPrinterEvents::~CPrinterEvents()
{
	Detach();
}

void CPrinterEvents::Attach(HANDLE hEvent, PXC6::IPXCPrinter* pPrinter)
{
	m_hEnvent	= hEvent;
	m_pPrinter	= pPrinter;
	AfxConnectionAdvise(pPrinter, PXC6::DIID__IPXCPrinterEvents, this->GetIDispatch(FALSE), FALSE, &m_dwConnectionCookie);
}

void CPrinterEvents::Detach()
{
	if (m_pPrinter)
	{
		AfxConnectionUnadvise(m_pPrinter, PXC6::DIID__IPXCPrinterEvents, this->GetIDispatch(FALSE), FALSE, m_dwConnectionCookie);
	}
	TRACE(L"Detach\n");
}

void CPrinterEvents::OnStartDoc		(long JobID, BSTR lpszDocName, BSTR lpszAppName)
{
	UNREFERENCED_PARAMETER(JobID);
	UNREFERENCED_PARAMETER(lpszDocName);
	UNREFERENCED_PARAMETER(lpszAppName);
	TRACE(L"OnStartDoc\n");
}

void CPrinterEvents::OnStartPage	(long JobID, long nPageNumber)
{
	UNREFERENCED_PARAMETER(JobID);
	UNREFERENCED_PARAMETER(nPageNumber);
	TRACE(L"OnStartPage\n");
}

void CPrinterEvents::OnEndPage		(long JobID, long nPageNumber)
{
	UNREFERENCED_PARAMETER(JobID);
	UNREFERENCED_PARAMETER(nPageNumber);
	TRACE(L"OnEndPage\n");
}

void CPrinterEvents::OnEndDoc		(long JobID, long nResult)
{
	UNREFERENCED_PARAMETER(JobID);
	UNREFERENCED_PARAMETER(nResult);
	TRACE(L"OnEndDoc\n");
}

void CPrinterEvents::OnFileSaved	(long JobID, BSTR lpszFileName)
{
	TRACE(L"OnFileSaved\n");
	UNREFERENCED_PARAMETER(JobID);
	UNREFERENCED_PARAMETER(lpszFileName);
	if (m_hEnvent != INVALID_HANDLE_VALUE)
		SetEvent(m_hEnvent);
}

void CPrinterEvents::OnFileSent		(long JobID, BSTR lpszFileName)
{
	TRACE(L"OnFileSent\n");
	UNREFERENCED_PARAMETER(JobID);
	UNREFERENCED_PARAMETER(lpszFileName);
}

void CPrinterEvents::OnError		(long JobID, long dwErrorCode)
{
	TRACE(L"OnError\n");
	UNREFERENCED_PARAMETER(JobID);
	UNREFERENCED_PARAMETER(dwErrorCode);
	if (m_hEnvent != INVALID_HANDLE_VALUE)
		SetEvent(m_hEnvent);
}

void CPrinterEvents::OnDocSpooled	(long JobID, BSTR lpszDocName, BSTR lpszAppName)
{
	TRACE(L"OnDocSpooled\n");
	UNREFERENCED_PARAMETER(JobID);
	UNREFERENCED_PARAMETER(lpszDocName);
	UNREFERENCED_PARAMETER(lpszAppName);
}

//////////////////////////////////////////////////////////////////////////
BEGIN_MESSAGE_MAP(CPrinterEvents, CCmdTarget)
END_MESSAGE_MAP()

BEGIN_DISPATCH_MAP(CPrinterEvents, CCmdTarget)
	DISP_FUNCTION_ID(CPrinterEvents, "OnStartDoc",		1,	OnStartDoc,		VT_EMPTY, VTS_I4 VTS_BSTR  VTS_BSTR)
	DISP_FUNCTION_ID(CPrinterEvents, "OnStartPage",		2,	OnStartPage,	VT_EMPTY, VTS_I4 VTS_I4)
	DISP_FUNCTION_ID(CPrinterEvents, "OnEndPage",		3,	OnEndPage,		VT_EMPTY, VTS_I4 VTS_I4)
	DISP_FUNCTION_ID(CPrinterEvents, "OnEndDoc",		4,	OnEndDoc,		VT_EMPTY, VTS_I4 VTS_I4)
	DISP_FUNCTION_ID(CPrinterEvents, "OnFileSaved",		5,	OnFileSaved,	VT_EMPTY, VTS_I4 VTS_BSTR)
	DISP_FUNCTION_ID(CPrinterEvents, "OnFileSent",		6,	OnFileSent,		VT_EMPTY, VTS_I4 VTS_BSTR)
	DISP_FUNCTION_ID(CPrinterEvents, "OnError",			7,	OnError,		VT_EMPTY, VTS_I4 VTS_I4)
	DISP_FUNCTION_ID(CPrinterEvents, "OnDocSpooled",	8,	OnDocSpooled,	VT_EMPTY, VTS_I4 VTS_BSTR VTS_BSTR)
END_DISPATCH_MAP()

BEGIN_INTERFACE_MAP(CPrinterEvents, CCmdTarget)
	INTERFACE_PART(CPrinterEvents, PXC6::DIID__IPXCPrinterEvents, Dispatch)
END_INTERFACE_MAP()
